sailthru-python-client
======================


For installation instructions, documentation, and examples please visit:
[http://getstarted.sailthru.com/new-for-developers-overview/api-client-library/python](http://getstarted.sailthru.com/new-for-developers-overview/api-client-library/python)

A simple client library to remotely access the `Sailthru REST API` as per [http://getstarted.sailthru.com/api](http://getstarted.sailthru.com/developers/api)

Python binding for [Sailthru API](http://getstarted.sailthru.com/api) based on [Requests](http://docs.python-requests.org/en/latest/)

It will make requests in `JSON` format.

Supports Python 2.6, 2.7, 3.3+

### Installation (Tested with Python 2.7.x)

Installing with [pip](http://www.pip-installer.org/):

    pip install sailthru-client
    
### Running tests
Install tox and then type:

    tox
